==> esp8266-0.3.0.crate: esp8266-0.3.0/src/timer/frc1_count.rs <==
#[doc = "Register `FRC1_COUNT` reader"]
pub struct R(crate::R<FRC1_COUNT_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<FRC1_COUNT_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<FRC1_COUNT_SPEC>> for R {
    fn from(reader: crate::R<FRC1_COUNT_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Field `frc1_count` reader - the current value of the counter. It is a decreasingcounter."]
pub struct FRC1_COUNT_R(crate::FieldReader<u32, u32>);
impl FRC1_COUNT_R {
    pub(crate) fn new(bits: u32) -> Self {
        FRC1_COUNT_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FRC1_COUNT_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bits 0:22 - the current value of the counter. It is a decreasingcounter."]
    #[inline(always)]
    pub fn frc1_count(&self) -> FRC1_COUNT_R {
        FRC1_COUNT_R::new((self.bits & 0x007f_ffff) as u32)
    }
}
#[doc = "the current value of the counter. It is a decreasingcounter.\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [frc1_count](index.html) module"]
pub struct FRC1_COUNT_SPEC;
impl crate::RegisterSpec for FRC1_COUNT_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [frc1_count::R](R) reader structure"]
impl crate::Readable for FRC1_COUNT_SPEC {
    type Reader = R;
}
#[doc = "`reset()` method sets FRC1_COUNT to value 0"]
impl crate::Resettable for FRC1_COUNT_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp8266-0.4.0.crate: esp8266-0.4.0/src/timer/frc1_count.rs <==
#[doc = "Register `FRC1_COUNT` reader"]
pub struct R(crate::R<FRC1_COUNT_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<FRC1_COUNT_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<FRC1_COUNT_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<FRC1_COUNT_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Field `frc1_count` reader - the current value of the counter. It is a decreasingcounter."]
pub struct FRC1_COUNT_R(crate::FieldReader<u32, u32>);
impl FRC1_COUNT_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        FRC1_COUNT_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for FRC1_COUNT_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bits 0:22 - the current value of the counter. It is a decreasingcounter."]
    #[inline(always)]
    pub fn frc1_count(&self) -> FRC1_COUNT_R {
        FRC1_COUNT_R::new((self.bits & 0x007f_ffff) as u32)
    }
}
#[doc = "the current value of the counter. It is a decreasingcounter.\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [frc1_count](index.html) module"]
pub struct FRC1_COUNT_SPEC;
impl crate::RegisterSpec for FRC1_COUNT_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [frc1_count::R](R) reader structure"]
impl crate::Readable for FRC1_COUNT_SPEC {
    type Reader = R;
}
#[doc = "`reset()` method sets FRC1_COUNT to value 0"]
impl crate::Resettable for FRC1_COUNT_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
